@@ -261,7 +261,7 @@ class VertSMS():
                        '8': '8',
                        '9': '9',
                        '0': '0',
-                       '*': ';',
+                       '*': '+',
                        '#': ';'}
 
             self.update_text(0)
@@ -306,8 +306,8 @@ class VertSMS():
     def slow_deletion(self, pressed, unused, unusedtoo):
 #        global backspace_pressed
 #        backspace_pressed = self.backspace_pressed        
-#        lock=thread.allocate_lock()
-        i=1        
+        lock=threading.allocate_lock()
+#        i=1        
 #        while i < 10:
 #          print i
 #          i = i+1
@@ -319,20 +319,29 @@ class VertSMS():
 #          lock.release()
 #        print self.backspace_pressed
 #        print "loop ended"
+        while self.backspacepressed:
+          lock.acquire()          
+          print "jou"
+          time.sleep(5)
+          lock.release()
 
     def backspace_hold(self, widget):
-        self.message_buffer.delete(self.message_buffer.get_start_iter(), self.message_buffer.get_end_iter())
+        self.backspacepressed = True
+#        self.message_buffer.delete(self.message_buffer.get_start_iter(), self.message_buffer.get_end_iter())
 #        global self.backspace_pressed
 #        global backspace_pressed        
 #        self.backspace_pressed = 1
 #        print "backspace pressed down"
 #        print self.backspace_pressed        
-#        thread.start_new_thread(self.slow_deletion,(self.lock,"jou", True))      
-#        self.slow_deletion("ju", True, "jou")            
+        thread.start_new_thread(self.slow_deletion,(self.lock,"jou", True))      
+#        self.slow_deletion("ju", True, "jou")          
+        self.backspacepressed = True
+        self.slow_deletion("jo", True, "omg")  
     def backspace_up(self, widget):
+        self.backspacepressed = False
 #        global backspace_pressed
 #        self.backspace_pressed = 0
-        print "backspace lifted"          
+#        print "backspace lifted"          
 #        self.slow_deletion("jou", False, "Empty")
         #  this needs to be done better
         #  i=0
@@ -398,10 +407,14 @@ class VertSMS():
     def input(self, feed):
         text = self.update_text(0)
         if self.message.is_focus():
-            self.message_buffer.set_text(text + feed)
+#            self.message_buffer.set_text(text + feed)
+#            offset = self.message_buffer.get_iter_at_mark(self.message_buffer.get_insert())
+            self.message_buffer.insert_at_cursor(feed)
+#            insert text to cursor location
         elif self.receiver.is_focus():
-            self.receiver_buffer.set_text(text + feed)
-
+#            self.receiver_buffer.set_text(text + feed)
+            self.receiver_buffer.insert_at_cursor(feed)
+            
     def addrbook(self, widget):
         start, end = self.receiver_buffer.get_bounds()
         oldbuffer = self.receiver_buffer.get_text(start, end)
